# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobufs/main.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobufs/main.proto',
  package='zaber.motion.protobufs',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x14protobufs/main.proto\x12\x16zaber.motion.protobufs\"\x1a\n\x07Request\x12\x0f\n\x07request\x18\x01 \x01(\t\"\xb9\x01\n\x08Response\x12?\n\x08response\x18\x01 \x01(\x0e\x32-.zaber.motion.protobufs.Response.ResponseType\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"!\n\x0cResponseType\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"\x16\n\x05\x45vent\x12\r\n\x05\x65vent\x18\x01 \x01(\t\"\x0e\n\x0c\x45mptyRequest\"\xdc\x01\n\x14OpenInterfaceRequest\x12R\n\x0einterface_type\x18\x01 \x01(\x0e\x32:.zaber.motion.protobufs.OpenInterfaceRequest.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\")\n\rInterfaceType\x12\x0f\n\x0bSERIAL_PORT\x10\x00\x12\x07\n\x03TCP\x10\x01\"-\n\x15OpenInterfaceResponse\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15\x43loseInterfaceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"E\n\x0fToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\"\n\x10ToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"r\n\x15GenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\"\xc8\x01\n\x16GenericCommandResponse\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"e\n GenericCommandResponseCollection\x12\x41\n\tresponses\x18\x02 \x03(\x0b\x32..zaber.motion.protobufs.GenericCommandResponse\"\xdc\x01\n\x14UnknownResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"\x83\x01\n\nAlertEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"t\n\x11\x44isconnectedEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"6\n\x0bTestRequest\x12\x14\n\x0creturn_error\x18\x01 \x01(\x08\x12\x11\n\tdata_ping\x18\x02 \x01(\t\"!\n\x0cTestResponse\x12\x11\n\tdata_pong\x18\x01 \x01(\t\"\x19\n\tTestEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"D\n\x15\x44\x65viceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x15\n\rfirst_address\x18\x02 \x01(\x05\"0\n\x16\x44\x65viceRenumberResponse\x12\x16\n\x0enumber_devices\x18\x01 \x01(\x05\"E\n\x13\x44\x65viceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"\'\n\x14\x44\x65viceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"`\n\x11\x44\x65viceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"n\n\x1a\x44\x65viceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"\xe4\x01\n\x11\x44\x65viceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12@\n\x04type\x18\x05 \x01(\x0e\x32\x32.zaber.motion.protobufs.DeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\"%\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\"`\n\x11\x44\x65viceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"=\n\x15\x44\x65viceIdentifyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"\xbd\x01\n\x0c\x41xisIdentity\x12\x15\n\ris_peripheral\x18\x01 \x01(\x08\x12\x15\n\rperipheral_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12@\n\taxis_type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.AxisIdentity.AxisType\"/\n\x08\x41xisType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"\xd3\x01\n\x0e\x44\x65viceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\naxis_count\x18\x04 \x01(\x05\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x32\n\x04\x61xes\x18\x06 \x03(\x0b\x32$.zaber.motion.protobufs.AxisIdentity\"@\n\x18\x44\x65viceGetIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"U\n\x19\x44\x65viceGetIdentityResponse\x12\x38\n\x08identity\x18\x01 \x01(\x0b\x32&.zaber.motion.protobufs.DeviceIdentity\"\'\n\x0fResetIdsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"I\n\x13\x44\x65viceIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\'\n\x14\x44\x65viceIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\">\n\x0f\x46irmwareVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\"]\n\x18\x44\x65viceGetWarningsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05\x63lear\x18\x04 \x01(\x08\"*\n\x19\x44\x65viceGetWarningsResponse\x12\r\n\x05\x66lags\x18\x01 \x03(\t\"6\n\x13SetLogOutputRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x11\n\tfile_path\x18\x02 \x01(\t\"l\n\x17\x44\x65viceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\")\n\x18\x44\x65viceGetSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"{\n\x17\x44\x65viceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"-\n\x1cToolsListSerialPortsResponse\x12\r\n\x05ports\x18\x01 \x03(\t\"I\n\x18SetDeviceDbSourceRequest\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x18\n\x10url_or_file_path\x18\x02 \x01(\t\"G\n\x1aToggleDeviceDbStoreRequest\x12\x11\n\ttoggle_on\x18\x01 \x01(\x08\x12\x16\n\x0estore_location\x18\x02 \x01(\t\"\x9e\x01\n\x15PrepareCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x18\n\x10\x63ommand_template\x18\x04 \x01(\t\x12\x37\n\nparameters\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\")\n\x16PrepareCommandResponse\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\"*\n\x0bMeasurement\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t*-\n\x0bMessageType\x12\t\n\x05REPLY\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x41LERT\x10\x02*\xc8\x03\n\x06\x45rrors\x12\x13\n\x0fREQUEST_TIMEOUT\x10\x00\x12\x15\n\x11\x43ONNECTION_CLOSED\x10\x01\x12\x14\n\x10INVALID_ARGUMENT\x10\x02\x12\x16\n\x12OUT_OF_REQUEST_IDS\x10\x03\x12\x12\n\x0eINVALID_PACKET\x10\x04\x12\x15\n\x11\x43ONNECTION_FAILED\x10\x05\x12\x13\n\x0fUNKNOWN_REQUEST\x10\x06\x12\x12\n\x0e\x43OMMAND_FAILED\x10\x07\x12\x14\n\x10\x44\x45VICE_DB_FAILED\x10\x08\x12\x10\n\x0cINVALID_DATA\x10\t\x12\x19\n\x15\x44\x45VICE_NOT_IDENTIFIED\x10\n\x12\x15\n\x11\x43ONVERSION_FAILED\x10\x0b\x12\x1a\n\x16\x44\x45VICE_NUMBER_CONFLICT\x10\x0c\x12\x13\n\x0fNO_DEVICE_FOUND\x10\r\x12\x18\n\x14MOVEMENT_INTERRUPTED\x10\x0e\x12\x13\n\x0fMOVEMENT_FAILED\x10\x0f\x12\x0c\n\x08IO_ERROR\x10\x10\x12\x14\n\x10INVALID_RESPONSE\x10\x11\x12\x11\n\rNOT_SUPPORTED\x10\x12\x12\x11\n\rDEVICE_FAILED\x10\x13\x12\x0c\n\x08OS_ERROR\x10\x14\x62\x06proto3')
)

_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='zaber.motion.protobufs.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPLY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALERT', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4273,
  serialized_end=4318,
)
_sym_db.RegisterEnumDescriptor(_MESSAGETYPE)

MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
_ERRORS = _descriptor.EnumDescriptor(
  name='Errors',
  full_name='zaber.motion.protobufs.Errors',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUEST_TIMEOUT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECTION_CLOSED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ARGUMENT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_REQUEST_IDS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PACKET', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECTION_FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_REQUEST', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_FAILED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_DB_FAILED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DATA', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_NOT_IDENTIFIED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FAILED', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_NUMBER_CONFLICT', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_DEVICE_FOUND', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOVEMENT_INTERRUPTED', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOVEMENT_FAILED', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IO_ERROR', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_RESPONSE', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_FAILED', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OS_ERROR', index=20, number=20,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4321,
  serialized_end=4777,
)
_sym_db.RegisterEnumDescriptor(_ERRORS)

Errors = enum_type_wrapper.EnumTypeWrapper(_ERRORS)
REPLY = 0
INFO = 1
ALERT = 2
REQUEST_TIMEOUT = 0
CONNECTION_CLOSED = 1
INVALID_ARGUMENT = 2
OUT_OF_REQUEST_IDS = 3
INVALID_PACKET = 4
CONNECTION_FAILED = 5
UNKNOWN_REQUEST = 6
COMMAND_FAILED = 7
DEVICE_DB_FAILED = 8
INVALID_DATA = 9
DEVICE_NOT_IDENTIFIED = 10
CONVERSION_FAILED = 11
DEVICE_NUMBER_CONFLICT = 12
NO_DEVICE_FOUND = 13
MOVEMENT_INTERRUPTED = 14
MOVEMENT_FAILED = 15
IO_ERROR = 16
INVALID_RESPONSE = 17
NOT_SUPPORTED = 18
DEVICE_FAILED = 19
OS_ERROR = 20


_RESPONSE_RESPONSETYPE = _descriptor.EnumDescriptor(
  name='ResponseType',
  full_name='zaber.motion.protobufs.Response.ResponseType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=229,
  serialized_end=262,
)
_sym_db.RegisterEnumDescriptor(_RESPONSE_RESPONSETYPE)

_OPENINTERFACEREQUEST_INTERFACETYPE = _descriptor.EnumDescriptor(
  name='InterfaceType',
  full_name='zaber.motion.protobufs.OpenInterfaceRequest.InterfaceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERIAL_PORT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TCP', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=484,
  serialized_end=525,
)
_sym_db.RegisterEnumDescriptor(_OPENINTERFACEREQUEST_INTERFACETYPE)

_DEVICEMOVEREQUEST_MOVETYPE = _descriptor.EnumDescriptor(
  name='MoveType',
  full_name='zaber.motion.protobufs.DeviceMoveRequest.MoveType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VEL', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2377,
  serialized_end=2414,
)
_sym_db.RegisterEnumDescriptor(_DEVICEMOVEREQUEST_MOVETYPE)

_AXISIDENTITY_AXISTYPE = _descriptor.EnumDescriptor(
  name='AxisType',
  full_name='zaber.motion.protobufs.AxisIdentity.AxisType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINEAR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROTARY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2720,
  serialized_end=2767,
)
_sym_db.RegisterEnumDescriptor(_AXISIDENTITY_AXISTYPE)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='zaber.motion.protobufs.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='zaber.motion.protobufs.Request.request', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=74,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='zaber.motion.protobufs.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='zaber.motion.protobufs.Response.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_type', full_name='zaber.motion.protobufs.Response.error_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='zaber.motion.protobufs.Response.error_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESPONSE_RESPONSETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=262,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='zaber.motion.protobufs.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='zaber.motion.protobufs.Event.event', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=286,
)


_EMPTYREQUEST = _descriptor.Descriptor(
  name='EmptyRequest',
  full_name='zaber.motion.protobufs.EmptyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=302,
)


_OPENINTERFACEREQUEST = _descriptor.Descriptor(
  name='OpenInterfaceRequest',
  full_name='zaber.motion.protobufs.OpenInterfaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_type', full_name='zaber.motion.protobufs.OpenInterfaceRequest.interface_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_name', full_name='zaber.motion.protobufs.OpenInterfaceRequest.port_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baud_rate', full_name='zaber.motion.protobufs.OpenInterfaceRequest.baud_rate', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='zaber.motion.protobufs.OpenInterfaceRequest.host_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='zaber.motion.protobufs.OpenInterfaceRequest.port', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPENINTERFACEREQUEST_INTERFACETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=525,
)


_OPENINTERFACERESPONSE = _descriptor.Descriptor(
  name='OpenInterfaceResponse',
  full_name='zaber.motion.protobufs.OpenInterfaceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.OpenInterfaceResponse.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=572,
)


_CLOSEINTERFACEREQUEST = _descriptor.Descriptor(
  name='CloseInterfaceRequest',
  full_name='zaber.motion.protobufs.CloseInterfaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.CloseInterfaceRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=619,
)


_TOSTRINGREQUEST = _descriptor.Descriptor(
  name='ToStringRequest',
  full_name='zaber.motion.protobufs.ToStringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.ToStringRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.ToStringRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.ToStringRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=690,
)


_TOSTRINGRESPONSE = _descriptor.Descriptor(
  name='ToStringResponse',
  full_name='zaber.motion.protobufs.ToStringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='to_str', full_name='zaber.motion.protobufs.ToStringResponse.to_str', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=692,
  serialized_end=726,
)


_GENERICCOMMANDREQUEST = _descriptor.Descriptor(
  name='GenericCommandRequest',
  full_name='zaber.motion.protobufs.GenericCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.GenericCommandRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.GenericCommandRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.GenericCommandRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.GenericCommandRequest.command', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_errors', full_name='zaber.motion.protobufs.GenericCommandRequest.check_errors', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=728,
  serialized_end=842,
)


_GENERICCOMMANDRESPONSE = _descriptor.Descriptor(
  name='GenericCommandResponse',
  full_name='zaber.motion.protobufs.GenericCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.GenericCommandResponse.device_address', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_number', full_name='zaber.motion.protobufs.GenericCommandResponse.axis_number', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply_flag', full_name='zaber.motion.protobufs.GenericCommandResponse.reply_flag', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='zaber.motion.protobufs.GenericCommandResponse.status', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning_flag', full_name='zaber.motion.protobufs.GenericCommandResponse.warning_flag', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.GenericCommandResponse.data', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='zaber.motion.protobufs.GenericCommandResponse.message_type', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=1045,
)


_GENERICCOMMANDRESPONSECOLLECTION = _descriptor.Descriptor(
  name='GenericCommandResponseCollection',
  full_name='zaber.motion.protobufs.GenericCommandResponseCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='zaber.motion.protobufs.GenericCommandResponseCollection.responses', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1148,
)


_UNKNOWNRESPONSEEVENT = _descriptor.Descriptor(
  name='UnknownResponseEvent',
  full_name='zaber.motion.protobufs.UnknownResponseEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.UnknownResponseEvent.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.UnknownResponseEvent.device_address', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_number', full_name='zaber.motion.protobufs.UnknownResponseEvent.axis_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply_flag', full_name='zaber.motion.protobufs.UnknownResponseEvent.reply_flag', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='zaber.motion.protobufs.UnknownResponseEvent.status', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning_flag', full_name='zaber.motion.protobufs.UnknownResponseEvent.warning_flag', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.UnknownResponseEvent.data', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='zaber.motion.protobufs.UnknownResponseEvent.message_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1371,
)


_ALERTEVENT = _descriptor.Descriptor(
  name='AlertEvent',
  full_name='zaber.motion.protobufs.AlertEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.AlertEvent.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.AlertEvent.device_address', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_number', full_name='zaber.motion.protobufs.AlertEvent.axis_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='zaber.motion.protobufs.AlertEvent.status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning_flag', full_name='zaber.motion.protobufs.AlertEvent.warning_flag', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.AlertEvent.data', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1374,
  serialized_end=1505,
)


_DISCONNECTEDEVENT = _descriptor.Descriptor(
  name='DisconnectedEvent',
  full_name='zaber.motion.protobufs.DisconnectedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DisconnectedEvent.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_type', full_name='zaber.motion.protobufs.DisconnectedEvent.error_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='zaber.motion.protobufs.DisconnectedEvent.error_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1623,
)


_TESTREQUEST = _descriptor.Descriptor(
  name='TestRequest',
  full_name='zaber.motion.protobufs.TestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='return_error', full_name='zaber.motion.protobufs.TestRequest.return_error', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_ping', full_name='zaber.motion.protobufs.TestRequest.data_ping', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1625,
  serialized_end=1679,
)


_TESTRESPONSE = _descriptor.Descriptor(
  name='TestResponse',
  full_name='zaber.motion.protobufs.TestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_pong', full_name='zaber.motion.protobufs.TestResponse.data_pong', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1681,
  serialized_end=1714,
)


_TESTEVENT = _descriptor.Descriptor(
  name='TestEvent',
  full_name='zaber.motion.protobufs.TestEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.TestEvent.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1716,
  serialized_end=1741,
)


_DEVICERENUMBERREQUEST = _descriptor.Descriptor(
  name='DeviceRenumberRequest',
  full_name='zaber.motion.protobufs.DeviceRenumberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceRenumberRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_address', full_name='zaber.motion.protobufs.DeviceRenumberRequest.first_address', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1743,
  serialized_end=1811,
)


_DEVICERENUMBERRESPONSE = _descriptor.Descriptor(
  name='DeviceRenumberResponse',
  full_name='zaber.motion.protobufs.DeviceRenumberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_devices', full_name='zaber.motion.protobufs.DeviceRenumberResponse.number_devices', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1813,
  serialized_end=1861,
)


_DEVICEDETECTREQUEST = _descriptor.Descriptor(
  name='DeviceDetectRequest',
  full_name='zaber.motion.protobufs.DeviceDetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceDetectRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identify_devices', full_name='zaber.motion.protobufs.DeviceDetectRequest.identify_devices', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1863,
  serialized_end=1932,
)


_DEVICEDETECTRESPONSE = _descriptor.Descriptor(
  name='DeviceDetectResponse',
  full_name='zaber.motion.protobufs.DeviceDetectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='zaber.motion.protobufs.DeviceDetectResponse.devices', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1934,
  serialized_end=1973,
)


_DEVICEHOMEREQUEST = _descriptor.Descriptor(
  name='DeviceHomeRequest',
  full_name='zaber.motion.protobufs.DeviceHomeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceHomeRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceHomeRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceHomeRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.DeviceHomeRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1975,
  serialized_end=2071,
)


_DEVICEWAITUNTILIDLEREQUEST = _descriptor.Descriptor(
  name='DeviceWaitUntilIdleRequest',
  full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='throw_error_on_fault', full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest.throw_error_on_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2183,
)


_DEVICEMOVEREQUEST = _descriptor.Descriptor(
  name='DeviceMoveRequest',
  full_name='zaber.motion.protobufs.DeviceMoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceMoveRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceMoveRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceMoveRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.DeviceMoveRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='zaber.motion.protobufs.DeviceMoveRequest.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg', full_name='zaber.motion.protobufs.DeviceMoveRequest.arg', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.DeviceMoveRequest.unit', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICEMOVEREQUEST_MOVETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2186,
  serialized_end=2414,
)


_DEVICESTOPREQUEST = _descriptor.Descriptor(
  name='DeviceStopRequest',
  full_name='zaber.motion.protobufs.DeviceStopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceStopRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceStopRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceStopRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.DeviceStopRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2416,
  serialized_end=2512,
)


_DEVICEIDENTIFYREQUEST = _descriptor.Descriptor(
  name='DeviceIdentifyRequest',
  full_name='zaber.motion.protobufs.DeviceIdentifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceIdentifyRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceIdentifyRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2514,
  serialized_end=2575,
)


_AXISIDENTITY = _descriptor.Descriptor(
  name='AxisIdentity',
  full_name='zaber.motion.protobufs.AxisIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_peripheral', full_name='zaber.motion.protobufs.AxisIdentity.is_peripheral', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peripheral_id', full_name='zaber.motion.protobufs.AxisIdentity.peripheral_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='zaber.motion.protobufs.AxisIdentity.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_type', full_name='zaber.motion.protobufs.AxisIdentity.axis_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AXISIDENTITY_AXISTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2578,
  serialized_end=2767,
)


_DEVICEIDENTITY = _descriptor.Descriptor(
  name='DeviceIdentity',
  full_name='zaber.motion.protobufs.DeviceIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='zaber.motion.protobufs.DeviceIdentity.device_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='zaber.motion.protobufs.DeviceIdentity.serial_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='zaber.motion.protobufs.DeviceIdentity.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_count', full_name='zaber.motion.protobufs.DeviceIdentity.axis_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firmware_version', full_name='zaber.motion.protobufs.DeviceIdentity.firmware_version', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axes', full_name='zaber.motion.protobufs.DeviceIdentity.axes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2770,
  serialized_end=2981,
)


_DEVICEGETIDENTITYREQUEST = _descriptor.Descriptor(
  name='DeviceGetIdentityRequest',
  full_name='zaber.motion.protobufs.DeviceGetIdentityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetIdentityRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetIdentityRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2983,
  serialized_end=3047,
)


_DEVICEGETIDENTITYRESPONSE = _descriptor.Descriptor(
  name='DeviceGetIdentityResponse',
  full_name='zaber.motion.protobufs.DeviceGetIdentityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identity', full_name='zaber.motion.protobufs.DeviceGetIdentityResponse.identity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3049,
  serialized_end=3134,
)


_RESETIDSREQUEST = _descriptor.Descriptor(
  name='ResetIdsRequest',
  full_name='zaber.motion.protobufs.ResetIdsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.ResetIdsRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3136,
  serialized_end=3175,
)


_DEVICEISBUSYREQUEST = _descriptor.Descriptor(
  name='DeviceIsBusyRequest',
  full_name='zaber.motion.protobufs.DeviceIsBusyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceIsBusyRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceIsBusyRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceIsBusyRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3177,
  serialized_end=3250,
)


_DEVICEISBUSYRESPONSE = _descriptor.Descriptor(
  name='DeviceIsBusyResponse',
  full_name='zaber.motion.protobufs.DeviceIsBusyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_busy', full_name='zaber.motion.protobufs.DeviceIsBusyResponse.is_busy', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3252,
  serialized_end=3291,
)


_FIRMWAREVERSION = _descriptor.Descriptor(
  name='FirmwareVersion',
  full_name='zaber.motion.protobufs.FirmwareVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='zaber.motion.protobufs.FirmwareVersion.major', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minor', full_name='zaber.motion.protobufs.FirmwareVersion.minor', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build', full_name='zaber.motion.protobufs.FirmwareVersion.build', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3293,
  serialized_end=3355,
)


_DEVICEGETWARNINGSREQUEST = _descriptor.Descriptor(
  name='DeviceGetWarningsRequest',
  full_name='zaber.motion.protobufs.DeviceGetWarningsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetWarningsRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetWarningsRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceGetWarningsRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clear', full_name='zaber.motion.protobufs.DeviceGetWarningsRequest.clear', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3357,
  serialized_end=3450,
)


_DEVICEGETWARNINGSRESPONSE = _descriptor.Descriptor(
  name='DeviceGetWarningsResponse',
  full_name='zaber.motion.protobufs.DeviceGetWarningsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='zaber.motion.protobufs.DeviceGetWarningsResponse.flags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3452,
  serialized_end=3494,
)


_SETLOGOUTPUTREQUEST = _descriptor.Descriptor(
  name='SetLogOutputRequest',
  full_name='zaber.motion.protobufs.SetLogOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='zaber.motion.protobufs.SetLogOutputRequest.mode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_path', full_name='zaber.motion.protobufs.SetLogOutputRequest.file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3496,
  serialized_end=3550,
)


_DEVICEGETSETTINGREQUEST = _descriptor.Descriptor(
  name='DeviceGetSettingRequest',
  full_name='zaber.motion.protobufs.DeviceGetSettingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setting', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.setting', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3552,
  serialized_end=3660,
)


_DEVICEGETSETTINGRESPONSE = _descriptor.Descriptor(
  name='DeviceGetSettingResponse',
  full_name='zaber.motion.protobufs.DeviceGetSettingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceGetSettingResponse.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3662,
  serialized_end=3703,
)


_DEVICESETSETTINGREQUEST = _descriptor.Descriptor(
  name='DeviceSetSettingRequest',
  full_name='zaber.motion.protobufs.DeviceSetSettingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setting', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.setting', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.unit', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3705,
  serialized_end=3828,
)


_TOOLSLISTSERIALPORTSRESPONSE = _descriptor.Descriptor(
  name='ToolsListSerialPortsResponse',
  full_name='zaber.motion.protobufs.ToolsListSerialPortsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ports', full_name='zaber.motion.protobufs.ToolsListSerialPortsResponse.ports', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3830,
  serialized_end=3875,
)


_SETDEVICEDBSOURCEREQUEST = _descriptor.Descriptor(
  name='SetDeviceDbSourceRequest',
  full_name='zaber.motion.protobufs.SetDeviceDbSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_type', full_name='zaber.motion.protobufs.SetDeviceDbSourceRequest.source_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_or_file_path', full_name='zaber.motion.protobufs.SetDeviceDbSourceRequest.url_or_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3877,
  serialized_end=3950,
)


_TOGGLEDEVICEDBSTOREREQUEST = _descriptor.Descriptor(
  name='ToggleDeviceDbStoreRequest',
  full_name='zaber.motion.protobufs.ToggleDeviceDbStoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='toggle_on', full_name='zaber.motion.protobufs.ToggleDeviceDbStoreRequest.toggle_on', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store_location', full_name='zaber.motion.protobufs.ToggleDeviceDbStoreRequest.store_location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3952,
  serialized_end=4023,
)


_PREPARECOMMANDREQUEST = _descriptor.Descriptor(
  name='PrepareCommandRequest',
  full_name='zaber.motion.protobufs.PrepareCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.PrepareCommandRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.PrepareCommandRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.PrepareCommandRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_template', full_name='zaber.motion.protobufs.PrepareCommandRequest.command_template', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='zaber.motion.protobufs.PrepareCommandRequest.parameters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4026,
  serialized_end=4184,
)


_PREPARECOMMANDRESPONSE = _descriptor.Descriptor(
  name='PrepareCommandResponse',
  full_name='zaber.motion.protobufs.PrepareCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.PrepareCommandResponse.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4186,
  serialized_end=4227,
)


_MEASUREMENT = _descriptor.Descriptor(
  name='Measurement',
  full_name='zaber.motion.protobufs.Measurement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.Measurement.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.Measurement.unit', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4229,
  serialized_end=4271,
)

_RESPONSE.fields_by_name['response'].enum_type = _RESPONSE_RESPONSETYPE
_RESPONSE.fields_by_name['error_type'].enum_type = _ERRORS
_RESPONSE_RESPONSETYPE.containing_type = _RESPONSE
_OPENINTERFACEREQUEST.fields_by_name['interface_type'].enum_type = _OPENINTERFACEREQUEST_INTERFACETYPE
_OPENINTERFACEREQUEST_INTERFACETYPE.containing_type = _OPENINTERFACEREQUEST
_GENERICCOMMANDRESPONSE.fields_by_name['message_type'].enum_type = _MESSAGETYPE
_GENERICCOMMANDRESPONSECOLLECTION.fields_by_name['responses'].message_type = _GENERICCOMMANDRESPONSE
_UNKNOWNRESPONSEEVENT.fields_by_name['message_type'].enum_type = _MESSAGETYPE
_DISCONNECTEDEVENT.fields_by_name['error_type'].enum_type = _ERRORS
_DEVICEMOVEREQUEST.fields_by_name['type'].enum_type = _DEVICEMOVEREQUEST_MOVETYPE
_DEVICEMOVEREQUEST_MOVETYPE.containing_type = _DEVICEMOVEREQUEST
_AXISIDENTITY.fields_by_name['axis_type'].enum_type = _AXISIDENTITY_AXISTYPE
_AXISIDENTITY_AXISTYPE.containing_type = _AXISIDENTITY
_DEVICEIDENTITY.fields_by_name['firmware_version'].message_type = _FIRMWAREVERSION
_DEVICEIDENTITY.fields_by_name['axes'].message_type = _AXISIDENTITY
_DEVICEGETIDENTITYRESPONSE.fields_by_name['identity'].message_type = _DEVICEIDENTITY
_PREPARECOMMANDREQUEST.fields_by_name['parameters'].message_type = _MEASUREMENT
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['EmptyRequest'] = _EMPTYREQUEST
DESCRIPTOR.message_types_by_name['OpenInterfaceRequest'] = _OPENINTERFACEREQUEST
DESCRIPTOR.message_types_by_name['OpenInterfaceResponse'] = _OPENINTERFACERESPONSE
DESCRIPTOR.message_types_by_name['CloseInterfaceRequest'] = _CLOSEINTERFACEREQUEST
DESCRIPTOR.message_types_by_name['ToStringRequest'] = _TOSTRINGREQUEST
DESCRIPTOR.message_types_by_name['ToStringResponse'] = _TOSTRINGRESPONSE
DESCRIPTOR.message_types_by_name['GenericCommandRequest'] = _GENERICCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['GenericCommandResponse'] = _GENERICCOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['GenericCommandResponseCollection'] = _GENERICCOMMANDRESPONSECOLLECTION
DESCRIPTOR.message_types_by_name['UnknownResponseEvent'] = _UNKNOWNRESPONSEEVENT
DESCRIPTOR.message_types_by_name['AlertEvent'] = _ALERTEVENT
DESCRIPTOR.message_types_by_name['DisconnectedEvent'] = _DISCONNECTEDEVENT
DESCRIPTOR.message_types_by_name['TestRequest'] = _TESTREQUEST
DESCRIPTOR.message_types_by_name['TestResponse'] = _TESTRESPONSE
DESCRIPTOR.message_types_by_name['TestEvent'] = _TESTEVENT
DESCRIPTOR.message_types_by_name['DeviceRenumberRequest'] = _DEVICERENUMBERREQUEST
DESCRIPTOR.message_types_by_name['DeviceRenumberResponse'] = _DEVICERENUMBERRESPONSE
DESCRIPTOR.message_types_by_name['DeviceDetectRequest'] = _DEVICEDETECTREQUEST
DESCRIPTOR.message_types_by_name['DeviceDetectResponse'] = _DEVICEDETECTRESPONSE
DESCRIPTOR.message_types_by_name['DeviceHomeRequest'] = _DEVICEHOMEREQUEST
DESCRIPTOR.message_types_by_name['DeviceWaitUntilIdleRequest'] = _DEVICEWAITUNTILIDLEREQUEST
DESCRIPTOR.message_types_by_name['DeviceMoveRequest'] = _DEVICEMOVEREQUEST
DESCRIPTOR.message_types_by_name['DeviceStopRequest'] = _DEVICESTOPREQUEST
DESCRIPTOR.message_types_by_name['DeviceIdentifyRequest'] = _DEVICEIDENTIFYREQUEST
DESCRIPTOR.message_types_by_name['AxisIdentity'] = _AXISIDENTITY
DESCRIPTOR.message_types_by_name['DeviceIdentity'] = _DEVICEIDENTITY
DESCRIPTOR.message_types_by_name['DeviceGetIdentityRequest'] = _DEVICEGETIDENTITYREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetIdentityResponse'] = _DEVICEGETIDENTITYRESPONSE
DESCRIPTOR.message_types_by_name['ResetIdsRequest'] = _RESETIDSREQUEST
DESCRIPTOR.message_types_by_name['DeviceIsBusyRequest'] = _DEVICEISBUSYREQUEST
DESCRIPTOR.message_types_by_name['DeviceIsBusyResponse'] = _DEVICEISBUSYRESPONSE
DESCRIPTOR.message_types_by_name['FirmwareVersion'] = _FIRMWAREVERSION
DESCRIPTOR.message_types_by_name['DeviceGetWarningsRequest'] = _DEVICEGETWARNINGSREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetWarningsResponse'] = _DEVICEGETWARNINGSRESPONSE
DESCRIPTOR.message_types_by_name['SetLogOutputRequest'] = _SETLOGOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetSettingRequest'] = _DEVICEGETSETTINGREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetSettingResponse'] = _DEVICEGETSETTINGRESPONSE
DESCRIPTOR.message_types_by_name['DeviceSetSettingRequest'] = _DEVICESETSETTINGREQUEST
DESCRIPTOR.message_types_by_name['ToolsListSerialPortsResponse'] = _TOOLSLISTSERIALPORTSRESPONSE
DESCRIPTOR.message_types_by_name['SetDeviceDbSourceRequest'] = _SETDEVICEDBSOURCEREQUEST
DESCRIPTOR.message_types_by_name['ToggleDeviceDbStoreRequest'] = _TOGGLEDEVICEDBSTOREREQUEST
DESCRIPTOR.message_types_by_name['PrepareCommandRequest'] = _PREPARECOMMANDREQUEST
DESCRIPTOR.message_types_by_name['PrepareCommandResponse'] = _PREPARECOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['Measurement'] = _MEASUREMENT
DESCRIPTOR.enum_types_by_name['MessageType'] = _MESSAGETYPE
DESCRIPTOR.enum_types_by_name['Errors'] = _ERRORS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), dict(
  DESCRIPTOR = _REQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Request)
  ))
_sym_db.RegisterMessage(Request)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Response)
  ))
_sym_db.RegisterMessage(Response)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), dict(
  DESCRIPTOR = _EVENT,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Event)
  ))
_sym_db.RegisterMessage(Event)

EmptyRequest = _reflection.GeneratedProtocolMessageType('EmptyRequest', (_message.Message,), dict(
  DESCRIPTOR = _EMPTYREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.EmptyRequest)
  ))
_sym_db.RegisterMessage(EmptyRequest)

OpenInterfaceRequest = _reflection.GeneratedProtocolMessageType('OpenInterfaceRequest', (_message.Message,), dict(
  DESCRIPTOR = _OPENINTERFACEREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OpenInterfaceRequest)
  ))
_sym_db.RegisterMessage(OpenInterfaceRequest)

OpenInterfaceResponse = _reflection.GeneratedProtocolMessageType('OpenInterfaceResponse', (_message.Message,), dict(
  DESCRIPTOR = _OPENINTERFACERESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OpenInterfaceResponse)
  ))
_sym_db.RegisterMessage(OpenInterfaceResponse)

CloseInterfaceRequest = _reflection.GeneratedProtocolMessageType('CloseInterfaceRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLOSEINTERFACEREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CloseInterfaceRequest)
  ))
_sym_db.RegisterMessage(CloseInterfaceRequest)

ToStringRequest = _reflection.GeneratedProtocolMessageType('ToStringRequest', (_message.Message,), dict(
  DESCRIPTOR = _TOSTRINGREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToStringRequest)
  ))
_sym_db.RegisterMessage(ToStringRequest)

ToStringResponse = _reflection.GeneratedProtocolMessageType('ToStringResponse', (_message.Message,), dict(
  DESCRIPTOR = _TOSTRINGRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToStringResponse)
  ))
_sym_db.RegisterMessage(ToStringResponse)

GenericCommandRequest = _reflection.GeneratedProtocolMessageType('GenericCommandRequest', (_message.Message,), dict(
  DESCRIPTOR = _GENERICCOMMANDREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandRequest)
  ))
_sym_db.RegisterMessage(GenericCommandRequest)

GenericCommandResponse = _reflection.GeneratedProtocolMessageType('GenericCommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _GENERICCOMMANDRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandResponse)
  ))
_sym_db.RegisterMessage(GenericCommandResponse)

GenericCommandResponseCollection = _reflection.GeneratedProtocolMessageType('GenericCommandResponseCollection', (_message.Message,), dict(
  DESCRIPTOR = _GENERICCOMMANDRESPONSECOLLECTION,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandResponseCollection)
  ))
_sym_db.RegisterMessage(GenericCommandResponseCollection)

UnknownResponseEvent = _reflection.GeneratedProtocolMessageType('UnknownResponseEvent', (_message.Message,), dict(
  DESCRIPTOR = _UNKNOWNRESPONSEEVENT,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.UnknownResponseEvent)
  ))
_sym_db.RegisterMessage(UnknownResponseEvent)

AlertEvent = _reflection.GeneratedProtocolMessageType('AlertEvent', (_message.Message,), dict(
  DESCRIPTOR = _ALERTEVENT,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.AlertEvent)
  ))
_sym_db.RegisterMessage(AlertEvent)

DisconnectedEvent = _reflection.GeneratedProtocolMessageType('DisconnectedEvent', (_message.Message,), dict(
  DESCRIPTOR = _DISCONNECTEDEVENT,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DisconnectedEvent)
  ))
_sym_db.RegisterMessage(DisconnectedEvent)

TestRequest = _reflection.GeneratedProtocolMessageType('TestRequest', (_message.Message,), dict(
  DESCRIPTOR = _TESTREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestRequest)
  ))
_sym_db.RegisterMessage(TestRequest)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), dict(
  DESCRIPTOR = _TESTRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestResponse)
  ))
_sym_db.RegisterMessage(TestResponse)

TestEvent = _reflection.GeneratedProtocolMessageType('TestEvent', (_message.Message,), dict(
  DESCRIPTOR = _TESTEVENT,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestEvent)
  ))
_sym_db.RegisterMessage(TestEvent)

DeviceRenumberRequest = _reflection.GeneratedProtocolMessageType('DeviceRenumberRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICERENUMBERREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceRenumberRequest)
  ))
_sym_db.RegisterMessage(DeviceRenumberRequest)

DeviceRenumberResponse = _reflection.GeneratedProtocolMessageType('DeviceRenumberResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEVICERENUMBERRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceRenumberResponse)
  ))
_sym_db.RegisterMessage(DeviceRenumberResponse)

DeviceDetectRequest = _reflection.GeneratedProtocolMessageType('DeviceDetectRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEDETECTREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceDetectRequest)
  ))
_sym_db.RegisterMessage(DeviceDetectRequest)

DeviceDetectResponse = _reflection.GeneratedProtocolMessageType('DeviceDetectResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEDETECTRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceDetectResponse)
  ))
_sym_db.RegisterMessage(DeviceDetectResponse)

DeviceHomeRequest = _reflection.GeneratedProtocolMessageType('DeviceHomeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEHOMEREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceHomeRequest)
  ))
_sym_db.RegisterMessage(DeviceHomeRequest)

DeviceWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('DeviceWaitUntilIdleRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEWAITUNTILIDLEREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceWaitUntilIdleRequest)
  ))
_sym_db.RegisterMessage(DeviceWaitUntilIdleRequest)

DeviceMoveRequest = _reflection.GeneratedProtocolMessageType('DeviceMoveRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEMOVEREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceMoveRequest)
  ))
_sym_db.RegisterMessage(DeviceMoveRequest)

DeviceStopRequest = _reflection.GeneratedProtocolMessageType('DeviceStopRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICESTOPREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceStopRequest)
  ))
_sym_db.RegisterMessage(DeviceStopRequest)

DeviceIdentifyRequest = _reflection.GeneratedProtocolMessageType('DeviceIdentifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEIDENTIFYREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIdentifyRequest)
  ))
_sym_db.RegisterMessage(DeviceIdentifyRequest)

AxisIdentity = _reflection.GeneratedProtocolMessageType('AxisIdentity', (_message.Message,), dict(
  DESCRIPTOR = _AXISIDENTITY,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.AxisIdentity)
  ))
_sym_db.RegisterMessage(AxisIdentity)

DeviceIdentity = _reflection.GeneratedProtocolMessageType('DeviceIdentity', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEIDENTITY,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIdentity)
  ))
_sym_db.RegisterMessage(DeviceIdentity)

DeviceGetIdentityRequest = _reflection.GeneratedProtocolMessageType('DeviceGetIdentityRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEGETIDENTITYREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIdentityRequest)
  ))
_sym_db.RegisterMessage(DeviceGetIdentityRequest)

DeviceGetIdentityResponse = _reflection.GeneratedProtocolMessageType('DeviceGetIdentityResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEGETIDENTITYRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIdentityResponse)
  ))
_sym_db.RegisterMessage(DeviceGetIdentityResponse)

ResetIdsRequest = _reflection.GeneratedProtocolMessageType('ResetIdsRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESETIDSREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ResetIdsRequest)
  ))
_sym_db.RegisterMessage(ResetIdsRequest)

DeviceIsBusyRequest = _reflection.GeneratedProtocolMessageType('DeviceIsBusyRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEISBUSYREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIsBusyRequest)
  ))
_sym_db.RegisterMessage(DeviceIsBusyRequest)

DeviceIsBusyResponse = _reflection.GeneratedProtocolMessageType('DeviceIsBusyResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEISBUSYRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIsBusyResponse)
  ))
_sym_db.RegisterMessage(DeviceIsBusyResponse)

FirmwareVersion = _reflection.GeneratedProtocolMessageType('FirmwareVersion', (_message.Message,), dict(
  DESCRIPTOR = _FIRMWAREVERSION,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.FirmwareVersion)
  ))
_sym_db.RegisterMessage(FirmwareVersion)

DeviceGetWarningsRequest = _reflection.GeneratedProtocolMessageType('DeviceGetWarningsRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEGETWARNINGSREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetWarningsRequest)
  ))
_sym_db.RegisterMessage(DeviceGetWarningsRequest)

DeviceGetWarningsResponse = _reflection.GeneratedProtocolMessageType('DeviceGetWarningsResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEGETWARNINGSRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetWarningsResponse)
  ))
_sym_db.RegisterMessage(DeviceGetWarningsResponse)

SetLogOutputRequest = _reflection.GeneratedProtocolMessageType('SetLogOutputRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETLOGOUTPUTREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetLogOutputRequest)
  ))
_sym_db.RegisterMessage(SetLogOutputRequest)

DeviceGetSettingRequest = _reflection.GeneratedProtocolMessageType('DeviceGetSettingRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEGETSETTINGREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetSettingRequest)
  ))
_sym_db.RegisterMessage(DeviceGetSettingRequest)

DeviceGetSettingResponse = _reflection.GeneratedProtocolMessageType('DeviceGetSettingResponse', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEGETSETTINGRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetSettingResponse)
  ))
_sym_db.RegisterMessage(DeviceGetSettingResponse)

DeviceSetSettingRequest = _reflection.GeneratedProtocolMessageType('DeviceSetSettingRequest', (_message.Message,), dict(
  DESCRIPTOR = _DEVICESETSETTINGREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetSettingRequest)
  ))
_sym_db.RegisterMessage(DeviceSetSettingRequest)

ToolsListSerialPortsResponse = _reflection.GeneratedProtocolMessageType('ToolsListSerialPortsResponse', (_message.Message,), dict(
  DESCRIPTOR = _TOOLSLISTSERIALPORTSRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToolsListSerialPortsResponse)
  ))
_sym_db.RegisterMessage(ToolsListSerialPortsResponse)

SetDeviceDbSourceRequest = _reflection.GeneratedProtocolMessageType('SetDeviceDbSourceRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETDEVICEDBSOURCEREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetDeviceDbSourceRequest)
  ))
_sym_db.RegisterMessage(SetDeviceDbSourceRequest)

ToggleDeviceDbStoreRequest = _reflection.GeneratedProtocolMessageType('ToggleDeviceDbStoreRequest', (_message.Message,), dict(
  DESCRIPTOR = _TOGGLEDEVICEDBSTOREREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToggleDeviceDbStoreRequest)
  ))
_sym_db.RegisterMessage(ToggleDeviceDbStoreRequest)

PrepareCommandRequest = _reflection.GeneratedProtocolMessageType('PrepareCommandRequest', (_message.Message,), dict(
  DESCRIPTOR = _PREPARECOMMANDREQUEST,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.PrepareCommandRequest)
  ))
_sym_db.RegisterMessage(PrepareCommandRequest)

PrepareCommandResponse = _reflection.GeneratedProtocolMessageType('PrepareCommandResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREPARECOMMANDRESPONSE,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.PrepareCommandResponse)
  ))
_sym_db.RegisterMessage(PrepareCommandResponse)

Measurement = _reflection.GeneratedProtocolMessageType('Measurement', (_message.Message,), dict(
  DESCRIPTOR = _MEASUREMENT,
  __module__ = 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Measurement)
  ))
_sym_db.RegisterMessage(Measurement)


# @@protoc_insertion_point(module_scope)



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #

from typing import TYPE_CHECKING, Optional, List
from .call import call, call_async, call_sync

from .protobufs import main_pb2
from .device_settings import DeviceSettings
from .axis import Axis
from .all_axes import AllAxes
from .warnings import Warnings
from .device_identity import DeviceIdentity
from .response import Response

if TYPE_CHECKING:
    from .connection import Connection


class Device:
    """
    Represents the controller part of one device - may be either a standalone controller or an integrated controller.
    """

    @property
    def connection(self) -> 'Connection':
        """
        Connection of this device.
        """
        return self._connection

    @property
    def device_address(self) -> int:
        """
        The device address uniquely identifies the device on the port.
        It can be configured or automatically assigned by the renumber command.
        """
        return self._device_address

    @property
    def settings(self) -> DeviceSettings:
        """
        Settings and properties of this device.
        """
        return self._settings

    @property
    def all_axes(self) -> AllAxes:
        """
        Virtual axis which allows you to target all axes of this device.
        """
        return self._all_axes

    @property
    def warnings(self) -> Warnings:
        """
        Warnings and faults of this device and all its axes.
        """
        return self._warnings

    @property
    def identity(self) -> Optional[DeviceIdentity]:
        """
        Identity of the device.
        """
        return self.__retrieve_identity()

    def __init__(self, connection: 'Connection', device_address: int):
        self._connection = connection
        self._device_address = device_address
        self._settings = DeviceSettings(self)
        self._all_axes = AllAxes(self)
        self._warnings = Warnings(self, 0)

    def identify(
            self
    ) -> DeviceIdentity:
        """
        Queries the device and the database, gathering information about the product.
        Without this information features such as unit conversions will not work.
        Usually, called automatically by detect devices method.

        Returns:
            Device identification data.
        """
        request = main_pb2.DeviceIdentifyRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        response = main_pb2.DeviceIdentity()
        call("device/identify", request, response)
        return DeviceIdentity.from_protobuf(response)

    async def identify_async(
            self
    ) -> DeviceIdentity:
        """
        Queries the device and the database, gathering information about the product.
        Without this information features such as unit conversions will not work.
        Usually, called automatically by detect devices method.

        Returns:
            Device identification data.
        """
        request = main_pb2.DeviceIdentifyRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        response = main_pb2.DeviceIdentity()
        await call_async("device/identify", request, response)
        return DeviceIdentity.from_protobuf(response)

    def generic_command(
            self,
            command: str,
            axis: int = 0,
            check_errors: bool = True
    ) -> Response:
        """
        Sends a generic ASCII command to this device.
        For more information refer to: [ASCII Protocol Manual](https://www.zaber.com/protocol-manual#topic_commands).

        Args:
            command: Command to send.
            axis: Optional axis number to send the command to.
            check_errors: Controls whether to throw exception when device rejects the command.

        Returns:
            A response to the command.
        """
        request = main_pb2.GenericCommandRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        request.command = command
        request.axis = axis
        request.check_errors = check_errors
        response = main_pb2.GenericCommandResponse()
        call("interface/generic_command", request, response)
        return Response.from_protobuf(response)

    async def generic_command_async(
            self,
            command: str,
            axis: int = 0,
            check_errors: bool = True
    ) -> Response:
        """
        Sends a generic ASCII command to this device.
        For more information refer to: [ASCII Protocol Manual](https://www.zaber.com/protocol-manual#topic_commands).

        Args:
            command: Command to send.
            axis: Optional axis number to send the command to.
            check_errors: Controls whether to throw exception when device rejects the command.

        Returns:
            A response to the command.
        """
        request = main_pb2.GenericCommandRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        request.command = command
        request.axis = axis
        request.check_errors = check_errors
        response = main_pb2.GenericCommandResponse()
        await call_async("interface/generic_command", request, response)
        return Response.from_protobuf(response)

    def generic_command_multi_response(
            self,
            command: str,
            axis: int = 0,
            check_errors: bool = True
    ) -> List[Response]:
        """
        Sends a generic ASCII command to this device and expect multiple responses.
        Responses are returned in order of arrival.
        For more information refer to: [ASCII Protocol Manual](https://www.zaber.com/protocol-manual#topic_commands).

        Args:
            command: Command to send.
            axis: Optional axis number to send the command to.
            check_errors: Controls whether to throw exception when device rejects the command.

        Returns:
            All responses to the command.
        """
        request = main_pb2.GenericCommandRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        request.command = command
        request.axis = axis
        request.check_errors = check_errors
        response = main_pb2.GenericCommandResponseCollection()
        call("interface/generic_command_multi_response", request, response)
        return [Response.from_protobuf(resp) for resp in response.responses]

    async def generic_command_multi_response_async(
            self,
            command: str,
            axis: int = 0,
            check_errors: bool = True
    ) -> List[Response]:
        """
        Sends a generic ASCII command to this device and expect multiple responses.
        Responses are returned in order of arrival.
        For more information refer to: [ASCII Protocol Manual](https://www.zaber.com/protocol-manual#topic_commands).

        Args:
            command: Command to send.
            axis: Optional axis number to send the command to.
            check_errors: Controls whether to throw exception when device rejects the command.

        Returns:
            All responses to the command.
        """
        request = main_pb2.GenericCommandRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        request.command = command
        request.axis = axis
        request.check_errors = check_errors
        response = main_pb2.GenericCommandResponseCollection()
        await call_async("interface/generic_command_multi_response", request, response)
        return [Response.from_protobuf(resp) for resp in response.responses]

    def generic_command_no_response(
            self,
            command: str,
            axis: int = 0
    ) -> None:
        """
        Sends a generic ASCII command to this device without expecting a response and without adding a message ID
        For more information refer to: [ASCII Protocol Manual](https://www.zaber.com/protocol-manual#topic_commands).

        Args:
            command: Command to send.
            axis: Optional axis number to send the command to.
        """
        request = main_pb2.GenericCommandRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        request.command = command
        request.axis = axis
        call("interface/generic_command_no_response", request)

    async def generic_command_no_response_async(
            self,
            command: str,
            axis: int = 0
    ) -> None:
        """
        Sends a generic ASCII command to this device without expecting a response and without adding a message ID
        For more information refer to: [ASCII Protocol Manual](https://www.zaber.com/protocol-manual#topic_commands).

        Args:
            command: Command to send.
            axis: Optional axis number to send the command to.
        """
        request = main_pb2.GenericCommandRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        request.command = command
        request.axis = axis
        await call_async("interface/generic_command_no_response", request)

    def axis(
            self,
            axis_number: int
    ) -> Axis:
        """
        Gets Axis class instance which allows you to control particular axis on this device.

        Args:
            axis_number: Number of axis intended to control.

        Returns:
            Axis instance.
        """
        if axis_number <= 0:
            raise ValueError('Invalid value, physical axes are numbered from 1.')

        return Axis(self, axis_number)

    def __repr__(
            self
    ) -> str:
        """
        Returns a string that represents the device.

        Returns:
            A string that represents the device.
        """
        request = main_pb2.ToStringRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        response = main_pb2.ToStringResponse()
        call_sync("device/device_to_string", request, response)
        return response.to_str

    def __retrieve_identity(
            self
    ) -> Optional[DeviceIdentity]:
        """
        Returns identity.

        Returns:
            Device identity.
        """
        request = main_pb2.DeviceGetIdentityRequest()
        request.interface_id = self.connection.interface_id
        request.device = self.device_address
        response = main_pb2.DeviceGetIdentityResponse()
        call_sync("device/get_identity", request, response)
        return DeviceIdentity.from_protobuf(response.identity) if response.identity is not None else None
